Imports System
Imports System.Drawing
Imports System.Collections
Imports System.ComponentModel
Imports System.Windows.Forms
Imports CADImport
Imports CADImport.FaceModule
Imports CADImport.CADImportForms

''' <summary>
''' Represents a form in which the properties of the line are set 
''' before adding it to the current CAD image.
''' </summary>
Public Class AddLineForm
    Inherits Form
    ' Events
    Public Event ResizeImageEvent As CADImportEventHandler

    ' Methods
    ''' <summary>
    ''' Initializes a new instance of the <see cref="!:AddEntityDemoApplication.AddLineForm">AddLineForm</see> class.
    ''' </summary>
    Public Sub New()
        Me.InitializeComponent()
        Me.setColorDlg = New ColorDialog
        Me.cbLineWeight.SelectedItem = ApplicationConstants.onestr
        Me.tbColor.Enabled = False
        MyBase.StartPosition = FormStartPosition.CenterScreen
    End Sub

    Private Sub addLineCancel_Click(ByVal sender As Object, ByVal e As EventArgs)
        MyBase.DialogResult = DialogResult.Cancel
        MyBase.Close()
    End Sub

    Private Sub addLineOK_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.line = New CADLine
        If (Me.setColorDlg.Color.Equals(Color.Black)) Then
            Me.line.Color = CADConst.clNone
        Else
            Me.line.Color = Me.setColorDlg.Color
        End If
        Try
            Me.line.Point = New DPoint(Convert.ToDouble(Me.tbX.Text), Convert.ToDouble(Me.tbY.Text), Convert.ToDouble(Me.tbZ.Text))
            Me.line.Point1 = New DPoint(Convert.ToDouble(Me.tbX2.Text), Convert.ToDouble(Me.tbY2.Text), Convert.ToDouble(Me.tbZ2.Text))
            Me.line.LineWeight = Convert.ToSingle(Me.cbLineWeight.Text, ApplicationConstants.numInfo)
            Me.cadImage.Converter.GetSection(ConvSection.Entities).AddEntity(Me.line)
            Me.cadImage.Converter.OnCreate(Me.line)
            Me.cadImage.Converter.Loads(Me.line)
            Me.OnResizeImage()
        Catch exception As FormatException
            MessageBox.Show(exception.Message, "Add Entity Demo", MessageBoxButtons.OK, MessageBoxIcon.Exclamation)
        End Try
        MyBase.DialogResult = DialogResult.OK
        MyBase.Close()
    End Sub

    ''' <summary>
    ''' Cleans up any resources being used.
    ''' </summary>
    ''' <param name="disposing">A value indicating if both managed and unmanaged resources have to be released (<b>true</b>) or only unmanaged (<b>false</b>). 
    ''' </param>
    Protected Overloads Sub Dispose(ByVal disposing As Boolean)
        If (disposing AndAlso (Not Me.components Is Nothing)) Then
            Me.components.Dispose()
        End If
        MyBase.Dispose(disposing)
    End Sub

#Region " Windows Form Designer generated code "
    ''' <summary>
    ''' Required method for Designer support - do not modify
    ''' the contents of this method with the code editor.
    ''' </summary>
    Private Sub InitializeComponent()
        Me.btnPickColor = New Button
        Me.tbColor = New TextBox
        Me.lbColor = New Label
        Me.tbZ = New TextBox
        Me.tbY = New TextBox
        Me.tbX = New TextBox
        Me.lbY = New Label
        Me.lbZ = New Label
        Me.lbX = New Label
        Me.tbZ2 = New TextBox
        Me.tbY2 = New TextBox
        Me.tbX2 = New TextBox
        Me.lbFirst = New Label
        Me.lbSec = New Label
        Me.line1 = New Label
        Me.line2 = New Label
        Me.line3 = New Label
        Me.line4 = New Label
        Me.line5 = New Label
        Me.vertLine1 = New Label
        Me.vertLine2 = New Label
        Me.cbLineWeight = New ComboBox
        Me.lbLineWeight = New Label
        Me.btnCancel = New Button
        Me.btnOK = New Button
        Me.label1 = New Label
        Me.label2 = New Label
        MyBase.SuspendLayout()
        Me.btnPickColor.FlatStyle = FlatStyle.System
        Me.btnPickColor.Location = New Point(&HCC, 15)
        Me.btnPickColor.Name = "btnPickColor"
        Me.btnPickColor.Size = New Size(&H4B, &H19)
        Me.btnPickColor.TabIndex = 7
        Me.btnPickColor.Text = "Pick a color"
        AddHandler Me.btnPickColor.Click, New System.EventHandler(AddressOf Me.pickColorButton_Click)
        Me.tbColor.BackColor = Color.Black
        Me.tbColor.Location = New Point(120, 15)
        Me.tbColor.Multiline = True
        Me.tbColor.Name = "tbColor"
        Me.tbColor.Size = New Size(&H4B, &H19)
        Me.tbColor.TabIndex = 6
        Me.tbColor.Text = ""
        Me.lbColor.Font = New Font("Microsoft Sans Serif", 9.75!, FontStyle.Regular, GraphicsUnit.Point, &HCC)
        Me.lbColor.Location = New Point(&H10, 15)
        Me.lbColor.Name = "lbColor"
        Me.lbColor.Size = New Size(&H38, &H18)
        Me.lbColor.TabIndex = 5
        Me.lbColor.Text = "Color :"
        Me.tbZ.Location = New Point(&H7A, &HB5)
        Me.tbZ.Name = "tbZ"
        Me.tbZ.Size = New Size(&H38, 20)
        Me.tbZ.TabIndex = 13
        Me.tbZ.Text = "0,0"
        Me.tbY.Location = New Point(&H7A, &H95)
        Me.tbY.Name = "tbY"
        Me.tbY.Size = New Size(&H38, 20)
        Me.tbY.TabIndex = 12
        Me.tbY.Text = "0,0"
        Me.tbX.Location = New Point(&H7A, &H75)
        Me.tbX.Name = "tbX"
        Me.tbX.Size = New Size(&H38, 20)
        Me.tbX.TabIndex = 11
        Me.tbX.Text = "0,0"
        Me.lbY.FlatStyle = FlatStyle.System
        Me.lbY.Font = New Font("Microsoft Sans Serif", 9.75!, FontStyle.Regular, GraphicsUnit.Point, 0)
        Me.lbY.Location = New Point(10, &H95)
        Me.lbY.Name = "lbY"
        Me.lbY.Size = New Size(&H62, 20)
        Me.lbY.TabIndex = 15
        Me.lbY.Text = "Y coordinate :"
        Me.lbY.TextAlign = ContentAlignment.MiddleCenter
        Me.lbZ.FlatStyle = FlatStyle.System
        Me.lbZ.Font = New Font("Microsoft Sans Serif", 9.75!, FontStyle.Regular, GraphicsUnit.Point, 0)
        Me.lbZ.Location = New Point(10, &HB5)
        Me.lbZ.Name = "lbZ"
        Me.lbZ.Size = New Size(&H62, 20)
        Me.lbZ.TabIndex = &H10
        Me.lbZ.Text = "Z coordinate :"
        Me.lbZ.TextAlign = ContentAlignment.MiddleCenter
        Me.lbX.FlatStyle = FlatStyle.System
        Me.lbX.Font = New Font("Microsoft Sans Serif", 9.75!, FontStyle.Regular, GraphicsUnit.Point, 0)
        Me.lbX.Location = New Point(10, &H75)
        Me.lbX.Name = "lbX"
        Me.lbX.Size = New Size(&H62, 20)
        Me.lbX.TabIndex = 14
        Me.lbX.Text = "X coordinate :"
        Me.lbX.TextAlign = ContentAlignment.MiddleCenter
        Me.tbZ2.Location = New Point(210, &HB5)
        Me.tbZ2.Name = "tbZ2"
        Me.tbZ2.Size = New Size(&H38, 20)
        Me.tbZ2.TabIndex = &H13
        Me.tbZ2.Text = "0,0"
        Me.tbY2.Location = New Point(210, &H95)
        Me.tbY2.Name = "tbY2"
        Me.tbY2.Size = New Size(&H38, 20)
        Me.tbY2.TabIndex = &H12
        Me.tbY2.Text = "1000,0"
        Me.tbX2.Location = New Point(210, &H75)
        Me.tbX2.Name = "tbX2"
        Me.tbX2.Size = New Size(&H38, 20)
        Me.tbX2.TabIndex = &H11
        Me.tbX2.Text = "1000,0"
        Me.lbFirst.FlatStyle = FlatStyle.System
        Me.lbFirst.Font = New Font("Microsoft Sans Serif", 9.75!, FontStyle.Regular, GraphicsUnit.Point, &HCC)
        Me.lbFirst.Location = New Point(&H72, &H58)
        Me.lbFirst.Name = "lbFirst"
        Me.lbFirst.Size = New Size(&H40, &H17)
        Me.lbFirst.TabIndex = 20
        Me.lbFirst.Text = "First point"
        Me.lbSec.FlatStyle = FlatStyle.System
        Me.lbSec.Font = New Font("Microsoft Sans Serif", 9.75!, FontStyle.Regular, GraphicsUnit.Point, &HCC)
        Me.lbSec.Location = New Point(&HC2, &H58)
        Me.lbSec.Name = "lbSec"
        Me.lbSec.Size = New Size(&H58, &H17)
        Me.lbSec.TabIndex = &H15
        Me.lbSec.Text = "Second point"
        Me.line1.BackColor = Color.Black
        Me.line1.FlatStyle = FlatStyle.System
        Me.line1.Location = New Point(13, &H55)
        Me.line1.Name = "line1"
        Me.line1.Size = New Size(&H10A, 1)
        Me.line1.TabIndex = &H16
        Me.line2.BackColor = Color.Black
        Me.line2.Location = New Point(14, &H6D)
        Me.line2.Name = "line2"
        Me.line2.Size = New Size(&H10A, 1)
        Me.line2.TabIndex = &H17
        Me.line3.BackColor = Color.Black
        Me.line3.FlatStyle = FlatStyle.System
        Me.line3.Location = New Point(14, &H8D)
        Me.line3.Name = "line3"
        Me.line3.Size = New Size(&H10A, 1)
        Me.line3.TabIndex = &H18
        Me.line4.BackColor = Color.Black
        Me.line4.FlatStyle = FlatStyle.System
        Me.line4.Location = New Point(14, &HAD)
        Me.line4.Name = "line4"
        Me.line4.Size = New Size(&H10A, 1)
        Me.line4.TabIndex = &H19
        Me.line5.BackColor = Color.Black
        Me.line5.FlatStyle = FlatStyle.System
        Me.line5.Location = New Point(14, &HCD)
        Me.line5.Name = "line5"
        Me.line5.Size = New Size(&H10A, 1)
        Me.line5.TabIndex = &H1A
        Me.vertLine1.BackColor = Color.Black
        Me.vertLine1.FlatStyle = FlatStyle.System
        Me.vertLine1.Location = New Point(&H6A, &H55)
        Me.vertLine1.Name = "vertLine1"
        Me.vertLine1.Size = New Size(1, 120)
        Me.vertLine1.TabIndex = &H1B
        Me.vertLine2.BackColor = Color.Black
        Me.vertLine2.FlatStyle = FlatStyle.System
        Me.vertLine2.Location = New Point(&HBD, &H55)
        Me.vertLine2.Name = "vertLine2"
        Me.vertLine2.Size = New Size(1, 120)
        Me.vertLine2.TabIndex = &H1C
        Me.cbLineWeight.DropDownStyle = ComboBoxStyle.DropDownList
        Me.cbLineWeight.Items.AddRange(New Object() {"0.1", "0.2", "0.3", "0.4", "0.5", "0.6", "0.7", "0.8", "0.9", "1.0", "1.1", "1.2", "1.3", "1.4", "1.5", "1.6", "1.7", "1.8", "1.9", "2.0", "2.1", "2.2", "2.3", "2.4", "2.5", "2.6", "2.7", "2.8", "2.9", "3.0", "3.1", "3.2", "3.3", "3.4", "3.5", "3.6", "3.7", "3.8", "3.9", "4.0", "4.1", "4.2", "4.3", "4.4", "4.5", "4.6", "4.7", "4.8", "4.9", "5.0", "5.1", "5.2", "5.3", "5.4", "5.5", "5.6", "5.7", "5.8", "5.9", "6.0", "6.1", "6.2", "6.3", "6.4", "6.5", "6.6", "6.7", "6.8", "6.9", "7.0", "7.1", "7.2", "7.3", "7.4", "7.5", "7.6", "7.7", "7.8", "7.9", "8.0", "8.1", "8.2", "8.3", "8.4", "8.5", "8.6", "8.7", "8.8", "8.9", "9.0", "9.1", "9.2", "9.3", "9.4", "9.5", "9.6", "9.7", "9.8", "9.9", "10.0"})
        Me.cbLineWeight.Location = New Point(120, &H31)
        Me.cbLineWeight.Name = "cbLineWeight"
        Me.cbLineWeight.Size = New Size(&H4B, &H15)
        Me.cbLineWeight.TabIndex = 30
        Me.lbLineWeight.Font = New Font("Microsoft Sans Serif", 9.75!, FontStyle.Regular, GraphicsUnit.Point, 0)
        Me.lbLineWeight.Location = New Point(&H10, &H35)
        Me.lbLineWeight.Name = "lbLineWeight"
        Me.lbLineWeight.Size = New Size(80, 20)
        Me.lbLineWeight.TabIndex = &H1D
        Me.lbLineWeight.Text = "Line weight :"
        Me.btnCancel.FlatStyle = FlatStyle.System
        Me.btnCancel.Location = New Point(&HCC, &HDD)
        Me.btnCancel.Name = "btnCancel"
        Me.btnCancel.Size = New Size(&H4B, &H19)
        Me.btnCancel.TabIndex = &H20
        Me.btnCancel.Text = "Cancel"
        AddHandler Me.btnCancel.Click, New System.EventHandler(AddressOf Me.addLineCancel_Click)
        Me.btnOK.FlatStyle = FlatStyle.System
        Me.btnOK.Location = New Point(120, &HDD)
        Me.btnOK.Name = "btnOK"
        Me.btnOK.Size = New Size(&H4B, &H19)
        Me.btnOK.TabIndex = &H1F
        Me.btnOK.Text = "OK"
        AddHandler Me.btnOK.Click, New System.EventHandler(AddressOf Me.addLineOK_Click)
        Me.label1.BackColor = Color.Black
        Me.label1.FlatStyle = FlatStyle.System
        Me.label1.Location = New Point(280, &H55)
        Me.label1.Name = "label1"
        Me.label1.Size = New Size(1, 120)
        Me.label1.TabIndex = &H21
        Me.label2.BackColor = Color.Black
        Me.label2.FlatStyle = FlatStyle.System
        Me.label2.Location = New Point(13, &H56)
        Me.label2.Name = "label2"
        Me.label2.Size = New Size(1, 120)
        Me.label2.TabIndex = &H22
        Me.AutoScaleBaseSize = New Size(5, 13)
        MyBase.ClientSize = New Size(&H124, &HFD)
        MyBase.Controls.Add(Me.label2)
        MyBase.Controls.Add(Me.label1)
        MyBase.Controls.Add(Me.btnCancel)
        MyBase.Controls.Add(Me.btnOK)
        MyBase.Controls.Add(Me.cbLineWeight)
        MyBase.Controls.Add(Me.lbLineWeight)
        MyBase.Controls.Add(Me.vertLine2)
        MyBase.Controls.Add(Me.vertLine1)
        MyBase.Controls.Add(Me.line5)
        MyBase.Controls.Add(Me.line4)
        MyBase.Controls.Add(Me.line3)
        MyBase.Controls.Add(Me.line2)
        MyBase.Controls.Add(Me.line1)
        MyBase.Controls.Add(Me.lbSec)
        MyBase.Controls.Add(Me.lbFirst)
        MyBase.Controls.Add(Me.tbZ2)
        MyBase.Controls.Add(Me.tbY2)
        MyBase.Controls.Add(Me.tbX2)
        MyBase.Controls.Add(Me.tbZ)
        MyBase.Controls.Add(Me.tbY)
        MyBase.Controls.Add(Me.tbX)
        MyBase.Controls.Add(Me.tbColor)
        MyBase.Controls.Add(Me.btnPickColor)
        MyBase.Controls.Add(Me.lbColor)
        MyBase.Controls.Add(Me.lbY)
        MyBase.Controls.Add(Me.lbZ)
        MyBase.Controls.Add(Me.lbX)
        MyBase.FormBorderStyle = FormBorderStyle.FixedSingle
        MyBase.MaximizeBox = False
        MyBase.Name = "AddLineForm"
        MyBase.StartPosition = FormStartPosition.CenterParent
        Me.Text = "Add Line"
        MyBase.ResumeLayout(False)
    End Sub
#End Region

    Public Sub OnResizeImage()
        'If (Not Me.ResizeImageEvent Is Nothing) Then
        RaiseEvent ResizeImageEvent()
        'End If
    End Sub

    Private Sub pickColorButton_Click(ByVal sender As Object, ByVal e As EventArgs)
        If (Me.setColorDlg.ShowDialog = DialogResult.OK) Then
            Me.tbColor.BackColor = Me.setColorDlg.Color
        End If
    End Sub


    ' Properties
    Public Property Image() As CADImage
        Get
            Return Me.cadImage
        End Get
        Set(ByVal value As CADImage)
            Me.cadImage = value
        End Set
    End Property


    ' Fields
    Private btnCancel As Button
    Private btnOK As Button
    Private btnPickColor As Button
    Private cadImage As CADImage
    Private cbLineWeight As ComboBox
    Private components As Container = Nothing
    Private label1 As Label
    Private label2 As Label
    Private lbColor As Label
    Private lbFirst As Label
    Private lbLineWeight As Label
    Private lbSec As Label
    Private lbX As Label
    Private lbY As Label
    Private lbZ As Label
    Private line As CADLine
    Private line1 As Label
    Private line2 As Label
    Private line3 As Label
    Private line4 As Label
    Private line5 As Label
    Private setColorDlg As ColorDialog
    Private tbColor As TextBox
    Private tbX As TextBox
    Private tbX2 As TextBox
    Private tbY As TextBox
    Private tbY2 As TextBox
    Private tbZ As TextBox
    Private tbZ2 As TextBox
    Private vertLine1 As Label
    Private vertLine2 As Label
End Class



