using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using System.Data;
using CADImport.FaceModule;
using CADImport.CADImportForms;

namespace CADImportNetDemos.CADEditorControlDemo
{
	#region Help
	/// <summary>
	/// Represents a main window of CADEditorControlDemo demo application
	/// </summary>
	#endregion
	public class MainForm : System.Windows.Forms.Form
	{	
		private bool dimVisible;
		private bool useWinEllipse;
		private bool showLineWeight;
		private bool whiteBackGround;
		private bool blackBackGround;
		private bool propPnVisible;
		private bool textVisible;
		private CADImport.CADImportControls.CADEditorControl cadEditorControl;		
		private SaveSettings svSet;
		private static SortedList settingsLst;				
		private static readonly string fileSettingsName;
		private string lngFile;
		private CADImport.FaceModule.MultipleLanguage mlng;
		private int curLngIndex;

		private System.Windows.Forms.MainMenu mainMenu;
		private System.Windows.Forms.MenuItem miFile;
		private System.Windows.Forms.MenuItem miPrintCustom;
		private System.Windows.Forms.MenuItem editMenuItem;
		private System.Windows.Forms.MenuItem miUndo;
		private System.Windows.Forms.MenuItem miRedo;
		private System.Windows.Forms.MenuItem miDelete;
		private System.Windows.Forms.MenuItem miCopy;
		private System.Windows.Forms.MenuItem miCut;
		private System.Windows.Forms.MenuItem miPaste;
		private System.Windows.Forms.MenuItem miView;
		private System.Windows.Forms.MenuItem miLng;
		private System.Windows.Forms.MenuItem miFloatLic;
		private System.Windows.Forms.MenuItem miAbout;		
		private System.Windows.Forms.MenuItem miRegister;		
		private System.ComponentModel.Container components = null;		
		private System.Windows.Forms.MenuItem miOpenFile;
		private System.Windows.Forms.MenuItem miSaveFile;
		private System.Windows.Forms.MenuItem miSaveAsDXF;
		private System.Windows.Forms.MenuItem miPrint;
		private System.Windows.Forms.MenuItem miPrintPrev;
		private System.Windows.Forms.MenuItem miClose;
		private System.Windows.Forms.MenuItem miSep;
		private System.Windows.Forms.MenuItem miExit;
		private System.Windows.Forms.MenuItem miCopyAsBMP;
		private System.Windows.Forms.MenuItem miShowEntitiesPanel;
		private System.Windows.Forms.MenuItem miZoomIn;
		private System.Windows.Forms.MenuItem miZoomOut;
		private System.Windows.Forms.MenuItem miScale;
		private System.Windows.Forms.MenuItem miZoom10;
		private System.Windows.Forms.MenuItem miZoom25;
		private System.Windows.Forms.MenuItem miZoom50;
		private System.Windows.Forms.MenuItem miZoom100;
		private System.Windows.Forms.MenuItem miZoom200;
		private System.Windows.Forms.MenuItem miZoom400;
		private System.Windows.Forms.MenuItem miZoom800;
		private System.Windows.Forms.MenuItem miFit;
		private System.Windows.Forms.MenuItem miShowSHXForm;
		private System.Windows.Forms.MenuItem miShowOptionsForm;
		private System.Windows.Forms.MenuItem miColorMode;
		private System.Windows.Forms.MenuItem miBlackMode;
		private System.Windows.Forms.MenuItem miWhiteBack;
		private System.Windows.Forms.MenuItem miBlackBack;
		private System.Windows.Forms.MenuItem miSep2;
		private System.Windows.Forms.MenuItem miShowLineWeight;
		private System.Windows.Forms.MenuItem miArcsSplit;
		private System.Windows.Forms.MenuItem miDimShow;
		private System.Windows.Forms.MenuItem miTextsShow;
		private System.Windows.Forms.MenuItem miSep3;
		private System.Windows.Forms.MenuItem miLayersShow;
		private System.Windows.Forms.MenuItem miSep5;
		private System.Windows.Forms.MenuItem mSep4;
		private System.Windows.Forms.MenuItem miCADFiles;
		private System.Windows.Forms.MenuItem miHelp;		

		static MainForm()
		{		
			fileSettingsName = Application.StartupPath + @"\Settings.txt";
		}

		#region Help
		/// <summary>
		/// Initializes a new instance of the <see cref="MainForm">MainForm</see> object.
		/// </summary>		
		#endregion Help
		public MainForm()
		{		
			InitializeComponent();
			InitializeSettings();
		}

		private void InitializeSettings()
		{
			dimVisible = true;
			useWinEllipse = false;
			showLineWeight = true;
			whiteBackGround = false;
			blackBackGround = true;
			propPnVisible = true;
			textVisible = true;
			#region protect
#if ((! floatprotect) && protect)
				this.miFloatLic.Enabled = false;
#endif
			#endregion									
			svSet = new SaveSettings(fileSettingsName);
			settingsLst = svSet.LoadOptions();			
			lngFile = ApplicationConstants.defaultstr;			
			curLngIndex = 0;						
			this.InitLng();
			if(settingsLst == null)
				CreateNewSettingsList();
			else
				SetSettings();					
			ReloadLNG();
			if(this.mainMenu.MenuItems[4].MenuItems[0].MenuItems.Count > this.curLngIndex)
				this.mainMenu.MenuItems[4].MenuItems[0].MenuItems[this.curLngIndex].Checked = true;
			SetAllFormsSettings();
			this.cadEditorControl.ChangeTextShow += new CADImport.CADImportForms.ChangeOptionsEventHandler(ChangeControlState);
			this.cadEditorControl.ChangeDimensionShow += new CADImport.CADImportForms.ChangeOptionsEventHandler(ChangeControlState);
			this.cadEditorControl.ChangeLineWeightShow += new CADImport.CADImportForms.ChangeOptionsEventHandler(ChangeControlState);
			this.cadEditorControl.ChangeBackgroundColor += new CADImport.CADImportForms.ChangeOptionsEventHandler(ChangeControlState);												
		}
		
		#region Help
		/// <summary>
		/// Disposes of the resources (other than memory) used by the MainForm.
		/// </summary>
		/// <param name="disposing">True to release both managed and unmanaged resources; false to release only unmanaged resources.</param>
		#endregion
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if (components != null) 
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			System.Resources.ResourceManager resources = new System.Resources.ResourceManager(typeof(MainForm));
			this.mainMenu = new System.Windows.Forms.MainMenu();
			this.miFile = new System.Windows.Forms.MenuItem();
			this.miOpenFile = new System.Windows.Forms.MenuItem();
			this.miSaveFile = new System.Windows.Forms.MenuItem();
			this.miSaveAsDXF = new System.Windows.Forms.MenuItem();
			this.miPrint = new System.Windows.Forms.MenuItem();
			this.miPrintCustom = new System.Windows.Forms.MenuItem();
			this.miPrintPrev = new System.Windows.Forms.MenuItem();
			this.miClose = new System.Windows.Forms.MenuItem();
			this.miSep = new System.Windows.Forms.MenuItem();
			this.miExit = new System.Windows.Forms.MenuItem();
			this.editMenuItem = new System.Windows.Forms.MenuItem();
			this.miCopyAsBMP = new System.Windows.Forms.MenuItem();
			this.miUndo = new System.Windows.Forms.MenuItem();
			this.miRedo = new System.Windows.Forms.MenuItem();
			this.miDelete = new System.Windows.Forms.MenuItem();
			this.miCopy = new System.Windows.Forms.MenuItem();
			this.miCut = new System.Windows.Forms.MenuItem();
			this.miPaste = new System.Windows.Forms.MenuItem();
			this.miView = new System.Windows.Forms.MenuItem();
			this.miShowEntitiesPanel = new System.Windows.Forms.MenuItem();
			this.miSep5 = new System.Windows.Forms.MenuItem();
			this.miZoomIn = new System.Windows.Forms.MenuItem();
			this.miZoomOut = new System.Windows.Forms.MenuItem();
			this.miScale = new System.Windows.Forms.MenuItem();
			this.miZoom10 = new System.Windows.Forms.MenuItem();
			this.miZoom25 = new System.Windows.Forms.MenuItem();
			this.miZoom50 = new System.Windows.Forms.MenuItem();
			this.miZoom100 = new System.Windows.Forms.MenuItem();
			this.miZoom200 = new System.Windows.Forms.MenuItem();
			this.miZoom400 = new System.Windows.Forms.MenuItem();
			this.miZoom800 = new System.Windows.Forms.MenuItem();
			this.miFit = new System.Windows.Forms.MenuItem();
			this.mSep4 = new System.Windows.Forms.MenuItem();
			this.miShowSHXForm = new System.Windows.Forms.MenuItem();
			this.miShowOptionsForm = new System.Windows.Forms.MenuItem();
			this.miCADFiles = new System.Windows.Forms.MenuItem();
			this.miColorMode = new System.Windows.Forms.MenuItem();
			this.miBlackMode = new System.Windows.Forms.MenuItem();
			this.miWhiteBack = new System.Windows.Forms.MenuItem();
			this.miBlackBack = new System.Windows.Forms.MenuItem();
			this.miSep2 = new System.Windows.Forms.MenuItem();
			this.miShowLineWeight = new System.Windows.Forms.MenuItem();
			this.miArcsSplit = new System.Windows.Forms.MenuItem();
			this.miDimShow = new System.Windows.Forms.MenuItem();
			this.miTextsShow = new System.Windows.Forms.MenuItem();
			this.miSep3 = new System.Windows.Forms.MenuItem();
			this.miLayersShow = new System.Windows.Forms.MenuItem();
			this.miHelp = new System.Windows.Forms.MenuItem();
			this.miLng = new System.Windows.Forms.MenuItem();
			this.miRegister = new System.Windows.Forms.MenuItem();
			this.miFloatLic = new System.Windows.Forms.MenuItem();
			this.miAbout = new System.Windows.Forms.MenuItem();
			this.cadEditorControl = new CADImport.CADImportControls.CADEditorControl();
			this.SuspendLayout();
			// 
			// mainMenu
			// 
			this.mainMenu.MenuItems.AddRange(new System.Windows.Forms.MenuItem[] {
																					 this.miFile,
																					 this.editMenuItem,
																					 this.miView,
																					 this.miCADFiles,
																					 this.miHelp});
			// 
			// miFile
			// 
			this.miFile.Index = 0;
			this.miFile.MenuItems.AddRange(new System.Windows.Forms.MenuItem[] {
																				   this.miOpenFile,
																				   this.miSaveFile,
																				   this.miSaveAsDXF,
																				   this.miPrint,
																				   this.miPrintCustom,
																				   this.miPrintPrev,
																				   this.miClose,
																				   this.miSep,
																				   this.miExit});
			this.miFile.Text = "&File";
			// 
			// miOpenFile
			// 
			this.miOpenFile.Index = 0;
			this.miOpenFile.Text = "Open Picture...";
			this.miOpenFile.Click += new System.EventHandler(this.miOpenFile_Click);
			// 
			// miSaveFile
			// 
			this.miSaveFile.Enabled = false;
			this.miSaveFile.Index = 1;
			this.miSaveFile.Text = "Save Picture...";
			this.miSaveFile.Click += new System.EventHandler(this.miSaveFile_Click);
			// 
			// miSaveAsDXF
			// 
			this.miSaveAsDXF.Enabled = false;
			this.miSaveAsDXF.Index = 2;
			this.miSaveAsDXF.Text = "Save as DXF...";
			this.miSaveAsDXF.Click += new System.EventHandler(this.miSaveAsDXF_Click);
			// 
			// miPrint
			// 
			this.miPrint.Enabled = false;
			this.miPrint.Index = 3;
			this.miPrint.Text = "Print ";
			this.miPrint.Click += new System.EventHandler(this.miPrint_Click);
			// 
			// miPrintCustom
			// 
			this.miPrintCustom.Enabled = false;
			this.miPrintCustom.Index = 4;
			this.miPrintCustom.Text = "Custom Print Preview...";
			this.miPrintCustom.Click += new System.EventHandler(this.miPrintCustom_Click);
			// 
			// miPrintPrev
			// 
			this.miPrintPrev.Enabled = false;
			this.miPrintPrev.Index = 5;
			this.miPrintPrev.Text = "Print Preview...";
			this.miPrintPrev.Click += new System.EventHandler(this.miPrintPrev_Click);
			// 
			// miClose
			// 
			this.miClose.Enabled = false;
			this.miClose.Index = 6;
			this.miClose.Text = "Close Picture";
			this.miClose.Click += new System.EventHandler(this.miClose_Click);
			// 
			// miSep
			// 
			this.miSep.Index = 7;
			this.miSep.Text = "-";
			// 
			// miExit
			// 
			this.miExit.Index = 8;
			this.miExit.Text = "Close";
			this.miExit.Click += new System.EventHandler(this.miExit_Click);
			// 
			// editMenuItem
			// 
			this.editMenuItem.Index = 1;
			this.editMenuItem.MenuItems.AddRange(new System.Windows.Forms.MenuItem[] {
																						 this.miCopyAsBMP,
																						 this.miUndo,
																						 this.miRedo,
																						 this.miDelete,
																						 this.miCopy,
																						 this.miCut,
																						 this.miPaste});
			this.editMenuItem.Text = "&Edit";
			// 
			// miCopyAsBMP
			// 
			this.miCopyAsBMP.Enabled = false;
			this.miCopyAsBMP.Index = 0;
			this.miCopyAsBMP.Text = "Copy as BMP";
			this.miCopyAsBMP.Click += new System.EventHandler(this.miCopyAsBMP_Click);
			// 
			// miUndo
			// 
			this.miUndo.Enabled = false;
			this.miUndo.Index = 1;
			this.miUndo.Shortcut = System.Windows.Forms.Shortcut.CtrlZ;
			this.miUndo.Text = "Undo";
			this.miUndo.Click += new System.EventHandler(this.miUndo_Click);
			// 
			// miRedo
			// 
			this.miRedo.Enabled = false;
			this.miRedo.Index = 2;
			this.miRedo.Shortcut = System.Windows.Forms.Shortcut.CtrlY;
			this.miRedo.Text = "Redo";
			this.miRedo.Click += new System.EventHandler(this.miRedo_Click);
			// 
			// miDelete
			// 
			this.miDelete.Enabled = false;
			this.miDelete.Index = 3;
			this.miDelete.Shortcut = System.Windows.Forms.Shortcut.Del;
			this.miDelete.Text = "Delete";
			this.miDelete.Click += new System.EventHandler(this.miDelete_Click);
			// 
			// miCopy
			// 
			this.miCopy.Enabled = false;
			this.miCopy.Index = 4;
			this.miCopy.Shortcut = System.Windows.Forms.Shortcut.CtrlC;
			this.miCopy.Text = "&Copy";
			this.miCopy.Click += new System.EventHandler(this.miCopy_Click);
			// 
			// miCut
			// 
			this.miCut.Enabled = false;
			this.miCut.Index = 5;
			this.miCut.Shortcut = System.Windows.Forms.Shortcut.CtrlX;
			this.miCut.Text = "Cu&t";
			this.miCut.Click += new System.EventHandler(this.miCut_Click);
			// 
			// miPaste
			// 
			this.miPaste.Enabled = false;
			this.miPaste.Index = 6;
			this.miPaste.Shortcut = System.Windows.Forms.Shortcut.CtrlV;
			this.miPaste.Text = "Paste";
			this.miPaste.Click += new System.EventHandler(this.miPaste_Click);
			// 
			// miView
			// 
			this.miView.Index = 2;
			this.miView.MenuItems.AddRange(new System.Windows.Forms.MenuItem[] {
																				   this.miShowEntitiesPanel,
																				   this.miSep5,
																				   this.miZoomIn,
																				   this.miZoomOut,
																				   this.miScale,
																				   this.miFit,
																				   this.mSep4,
																				   this.miShowSHXForm,
																				   this.miShowOptionsForm});
			this.miView.Text = "&View";
			// 
			// miShowEntitiesPanel
			// 
			this.miShowEntitiesPanel.Checked = true;
			this.miShowEntitiesPanel.Index = 0;
			this.miShowEntitiesPanel.Text = "Show entities panel";
			this.miShowEntitiesPanel.Click += new System.EventHandler(this.miShowEntitiesPanel_Click);
			// 
			// miSep5
			// 
			this.miSep5.Index = 1;
			this.miSep5.Text = "-";
			// 
			// miZoomIn
			// 
			this.miZoomIn.Enabled = false;
			this.miZoomIn.Index = 2;
			this.miZoomIn.Text = "Zoom In (+)";
			this.miZoomIn.Click += new System.EventHandler(this.miZoomIn_Click);
			// 
			// miZoomOut
			// 
			this.miZoomOut.Enabled = false;
			this.miZoomOut.Index = 3;
			this.miZoomOut.Text = "Zoom Out (-)";
			this.miZoomOut.Click += new System.EventHandler(this.miZoomOut_Click);
			// 
			// miScale
			// 
			this.miScale.Enabled = false;
			this.miScale.Index = 4;
			this.miScale.MenuItems.AddRange(new System.Windows.Forms.MenuItem[] {
																					this.miZoom10,
																					this.miZoom25,
																					this.miZoom50,
																					this.miZoom100,
																					this.miZoom200,
																					this.miZoom400,
																					this.miZoom800});
			this.miScale.Text = "Scale";
			// 
			// miZoom10
			// 
			this.miZoom10.Index = 0;
			this.miZoom10.Text = "10%";
			this.miZoom10.Click += new System.EventHandler(this.miZoom_Click);
			// 
			// miZoom25
			// 
			this.miZoom25.Index = 1;
			this.miZoom25.Text = "25%";
			this.miZoom25.Click += new System.EventHandler(this.miZoom_Click);
			// 
			// miZoom50
			// 
			this.miZoom50.Index = 2;
			this.miZoom50.Text = "50%";
			this.miZoom50.Click += new System.EventHandler(this.miZoom_Click);
			// 
			// miZoom100
			// 
			this.miZoom100.Index = 3;
			this.miZoom100.Text = "100%";
			this.miZoom100.Click += new System.EventHandler(this.miZoom_Click);
			// 
			// miZoom200
			// 
			this.miZoom200.Index = 4;
			this.miZoom200.Text = "200%";
			this.miZoom200.Click += new System.EventHandler(this.miZoom_Click);
			// 
			// miZoom400
			// 
			this.miZoom400.Index = 5;
			this.miZoom400.Text = "400%";
			this.miZoom400.Click += new System.EventHandler(this.miZoom_Click);
			// 
			// miZoom800
			// 
			this.miZoom800.Index = 6;
			this.miZoom800.Text = "800%";
			this.miZoom800.Click += new System.EventHandler(this.miZoom_Click);
			// 
			// miFit
			// 
			this.miFit.Enabled = false;
			this.miFit.Index = 5;
			this.miFit.Text = "Fit drawing to window";
			this.miFit.Click += new System.EventHandler(this.miFit_Click);
			// 
			// mSep4
			// 
			this.mSep4.Index = 6;
			this.mSep4.Text = "-";
			// 
			// miShowSHXForm
			// 
			this.miShowSHXForm.Index = 7;
			this.miShowSHXForm.Text = "SHX Fonts";
			this.miShowSHXForm.Click += new System.EventHandler(this.miShowSHXForm_Click);
			// 
			// miShowOptionsForm
			// 
			this.miShowOptionsForm.Index = 8;
			this.miShowOptionsForm.Text = "Options";
			this.miShowOptionsForm.Click += new System.EventHandler(this.miOptions_Click);
			// 
			// miCADFiles
			// 
			this.miCADFiles.Index = 3;
			this.miCADFiles.MenuItems.AddRange(new System.Windows.Forms.MenuItem[] {
																					   this.miColorMode,
																					   this.miBlackMode,
																					   this.miWhiteBack,
																					   this.miBlackBack,
																					   this.miSep2,
																					   this.miShowLineWeight,
																					   this.miArcsSplit,
																					   this.miDimShow,
																					   this.miTextsShow,
																					   this.miSep3,
																					   this.miLayersShow});
			this.miCADFiles.Text = "&CAD files";
			// 
			// miColorMode
			// 
			this.miColorMode.Checked = true;
			this.miColorMode.Enabled = false;
			this.miColorMode.Index = 0;
			this.miColorMode.RadioCheck = true;
			this.miColorMode.Text = "Color drawing";
			this.miColorMode.Click += new System.EventHandler(this.miColorMode_Click);
			// 
			// miBlackMode
			// 
			this.miBlackMode.Enabled = false;
			this.miBlackMode.Index = 1;
			this.miBlackMode.RadioCheck = true;
			this.miBlackMode.Text = "Black drawing";
			this.miBlackMode.Click += new System.EventHandler(this.miBlackMode_Click);
			// 
			// miWhiteBack
			// 
			this.miWhiteBack.Enabled = false;
			this.miWhiteBack.Index = 2;
			this.miWhiteBack.RadioCheck = true;
			this.miWhiteBack.Text = "White Background";
			this.miWhiteBack.Click += new System.EventHandler(this.miWhiteBack_Click);
			// 
			// miBlackBack
			// 
			this.miBlackBack.Checked = true;
			this.miBlackBack.Enabled = false;
			this.miBlackBack.Index = 3;
			this.miBlackBack.RadioCheck = true;
			this.miBlackBack.Text = "Black Background";
			this.miBlackBack.Click += new System.EventHandler(this.miBlackBack_Click);
			// 
			// miSep2
			// 
			this.miSep2.Enabled = false;
			this.miSep2.Index = 4;
			this.miSep2.Text = "-";
			// 
			// miShowLineWeight
			// 
			this.miShowLineWeight.Checked = true;
			this.miShowLineWeight.Enabled = false;
			this.miShowLineWeight.Index = 5;
			this.miShowLineWeight.Text = "Show Lineweight";
			this.miShowLineWeight.Click += new System.EventHandler(this.miShowLineWeight_Click);
			// 
			// miArcsSplit
			// 
			this.miArcsSplit.Checked = true;
			this.miArcsSplit.Enabled = false;
			this.miArcsSplit.Index = 6;
			this.miArcsSplit.Text = "Arcs Splitted";
			this.miArcsSplit.Click += new System.EventHandler(this.miArcsSplit_Click);
			// 
			// miDimShow
			// 
			this.miDimShow.Checked = true;
			this.miDimShow.Enabled = false;
			this.miDimShow.Index = 7;
			this.miDimShow.Text = "Dimensions Show";
			this.miDimShow.Click += new System.EventHandler(this.miDimShow_Click);
			// 
			// miTextsShow
			// 
			this.miTextsShow.Checked = true;
			this.miTextsShow.Enabled = false;
			this.miTextsShow.Index = 8;
			this.miTextsShow.Text = "Texts Show";
			this.miTextsShow.Click += new System.EventHandler(this.miTextsShow_Click);
			// 
			// miSep3
			// 
			this.miSep3.Enabled = false;
			this.miSep3.Index = 9;
			this.miSep3.Text = "-";
			// 
			// miLayersShow
			// 
			this.miLayersShow.Enabled = false;
			this.miLayersShow.Index = 10;
			this.miLayersShow.Text = "Show Layers";
			this.miLayersShow.Click += new System.EventHandler(this.miLayersShow_Click);
			// 
			// miHelp
			// 
			this.miHelp.Index = 4;
			this.miHelp.MenuItems.AddRange(new System.Windows.Forms.MenuItem[] {
																				   this.miLng,
																				   this.miRegister,
																				   this.miFloatLic,
																				   this.miAbout});
			this.miHelp.Text = "?";
			// 
			// miLng
			// 
			this.miLng.Index = 0;
			this.miLng.Text = "Language";
			// 
			// miRegister
			// 
			this.miRegister.Index = 1;
			this.miRegister.Text = "Register ";
			this.miRegister.Click += new System.EventHandler(this.miRegister_Click);
			// 
			// miFloatLic
			// 
			this.miFloatLic.Index = 2;
			this.miFloatLic.Text = "Floating License Registration...";
			this.miFloatLic.Click += new System.EventHandler(this.miFloatLic_Click);
			// 
			// miAbout
			// 
			this.miAbout.Index = 3;
			this.miAbout.Text = "About...";
			this.miAbout.Click += new System.EventHandler(this.miAbout_Click);
			// 
			// cadEditorControl
			// 
			this.cadEditorControl.ColorDraw = true;
			this.cadEditorControl.DimensionVisible = true;
			this.cadEditorControl.Dock = System.Windows.Forms.DockStyle.Fill;
			this.cadEditorControl.EnableSnap = true;
			this.cadEditorControl.EndPoint = new System.Drawing.Point(0, 0);
			this.cadEditorControl.EntityPropertyGridVisible = true;
			this.cadEditorControl.EntityTreeVisible = true;
			this.cadEditorControl.ImageBaseSize = ((System.Drawing.SizeF)(resources.GetObject("cadEditorControl.ImageBaseSize")));
			this.cadEditorControl.ImagePosition = ((System.Drawing.PointF)(resources.GetObject("cadEditorControl.ImagePosition")));
			this.cadEditorControl.ImageScale = 1F;
			this.cadEditorControl.InFileName = "";
			this.cadEditorControl.Location = new System.Drawing.Point(0, 0);
			this.cadEditorControl.Name = "cadEditorControl";
			this.cadEditorControl.OutFileName = "";
			this.cadEditorControl.PreviousImagePosition = ((System.Drawing.PointF)(resources.GetObject("cadEditorControl.PreviousImagePosition")));
			this.cadEditorControl.PreviousImageScale = 1F;
			this.cadEditorControl.PropertyEntityPanelVisible = true;
			this.cadEditorControl.ShowLineWeight = true;
			this.cadEditorControl.Size = new System.Drawing.Size(632, 462);
			this.cadEditorControl.StartPoint = new System.Drawing.Point(0, 0);
			this.cadEditorControl.StatusBarPanelVisible = true;
			this.cadEditorControl.TabIndex = 0;
			this.cadEditorControl.TextVisible = true;
			this.cadEditorControl.ToolsPanelVisible = true;
			this.cadEditorControl.EndLoadFile += new CADImport.CADImportForms.ChangeOptionsEventHandler(this.cadEditorControl_EndLoadFile);
			// 
			// MainForm
			// 
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
			this.ClientSize = new System.Drawing.Size(632, 462);
			this.Controls.Add(this.cadEditorControl);
			this.Menu = this.mainMenu;
			this.Name = "MainForm";
			this.Text = "Editor";
			this.Closing += new System.ComponentModel.CancelEventHandler(this.MainForm_Closing);
			this.ResumeLayout(false);

		}
		#endregion

		[STAThread]
		static void Main(string[] args) 
		{
			Application.EnableVisualStyles();
			Application.DoEvents();			
			Application.Run(new MainForm());
		}

		
		private void ChangeControlState(bool val)
		{
			this.miTextsShow.Checked = this.cadEditorControl.TextVisible;
			this.miDimShow.Checked = this.cadEditorControl.DimensionVisible;
			this.miShowLineWeight.Checked = this.cadEditorControl.ShowLineWeight;
			bool colorblack = this.cadEditorControl.Image.BackgroundColor.Equals(Color.Black);
			this.miBlackBack.Checked = colorblack;
			this.miWhiteBack.Checked = ! colorblack;
			this.miShowEntitiesPanel.Checked = this.cadEditorControl.EntityTreeVisible;
			this.miColorMode.Checked = this.cadEditorControl.ColorDraw;
			this.miBlackMode.Checked = ! this.cadEditorControl.ColorDraw;
		}

		private void InitLng()
		{
			mlng = new MultipleLanguage(this.GetType());			
			if(this.mainMenu != null)
				mlng.SaveNameMenuItem(this.mainMenu.MenuItems);
			if(this.ContextMenu != null)
				mlng.SaveNameMenuItem(this.ContextMenu.MenuItems);
			mlng.SaveNameNoNameElement(this.Controls);			
		}

		private void SetAllFormsSettings()
		{	
			this.cadEditorControl.SetAllFormsLanguageSettings(mlng.Path, lngFile);				
			this.cadEditorControl.OptionsForm.ChangeLngPath += new CADImport.CADImportForms.ChangeLngPathEventHandler(ReloadLNG);
			this.cadEditorControl.OptionsForm.ChangeLanguage += new CADImport.CADImportForms.ChangeLanguageEventHandler(ChangeLanguage);						
		}		

		internal void ReloadLNG(string val)
		{
			this.mainMenu.MenuItems[4].MenuItems[0].MenuItems.Clear();
			mlng.Path = val;
			mlng.LoadLngFileList(this.mainMenu.MenuItems[4].MenuItems[0], new System.EventHandler(LanguageSelect_Click));
			if(this.mainMenu.MenuItems[4].MenuItems[0].MenuItems.Count > this.curLngIndex)
				this.mainMenu.MenuItems[4].MenuItems[0].MenuItems[this.curLngIndex].Checked = true;
		}
		
		private void InitSettings()
		{			
			svSet = new SaveSettings(fileSettingsName);
			settingsLst = svSet.LoadOptions();
			if(settingsLst != null)
			{
				string key = ApplicationConstants.languagepath;
				if(settingsLst.ContainsKey(key))
					this.mlng.Path = Convert.ToString(settingsLst[key]);
			} 
			else			
				this.mlng.Path = @".\Languages";			
			mlng.LoadLngFileList(this.mainMenu.MenuItems[4].MenuItems[0], new System.EventHandler(LanguageSelect_Click));
			if(settingsLst == null)
				CreateNewSettingsList();
			else
				SetSettings();
		}

		private void LanguageSelect_Click(object sender, System.EventArgs e)
		{
			if(!(sender is MenuItem)) 
				return;
			MenuItem mn = (sender as MenuItem);
			curLngIndex = (byte)mn.Index;
			lngFile = mn.Text + ApplicationConstants.lngextstr; 
			this.cadEditorControl.SetAllFormsLanguageSettings(this.mlng.Path, lngFile);
			SetLNG();
			this.cadEditorControl.ChangeControlState();
		}

		#region Help
#if RUSHELP
		/// <summary>
		///     
		/// </summary>
		/// <param name="val"> </param>
		/// <param name="index">     </param>
#else
		/// <summary>
		/// Sets specified linguage for the application
		/// </summary>
		/// <param name="val">A language to set</param>
		/// <param name="index">An index of a language in the languages list</param>
#endif
		#endregion
		public void ChangeLanguage(string val, int index)
		{
			curLngIndex = index;
			lngFile = val + ApplicationConstants.lngextstr; 
			this.cadEditorControl.SetAllFormsLanguageSettings(this.mlng.Path, lngFile);
			SetLNG();
			this.cadEditorControl.ChangeControlState();
		}	

		private void SetLNG()
		{
			mlng.LoadLNG(lngFile);
			mlng.RestoreLanguage(this.Controls, this.Menu);
			this.mainMenu.MenuItems[4].MenuItems[0].MenuItems.Clear();
			mlng.LoadLngFileList(this.mainMenu.MenuItems[4].MenuItems[0], new System.EventHandler(LanguageSelect_Click));
			this.Text = ApplicationConstants.appnamestr;
			this.Text = mlng.SetLanguage(this.Controls, this.Menu, this.Text);
			if(this.mainMenu.MenuItems[4].MenuItems[0].MenuItems.Count > this.curLngIndex)
				this.mainMenu.MenuItems[4].MenuItems[0].MenuItems[this.curLngIndex].Checked = true;
		}

		internal void SetSettings()
		{
			if(settingsLst == null)
				return;
			string tmp; 
			int cn = 0;
			//Language path
			string key = ApplicationConstants.languagepath;
			if(settingsLst.ContainsKey(key))
				this.mlng.Path = Convert.ToString(settingsLst[key]);
			//Language
			key = ApplicationConstants.languagestr;
			if(settingsLst.ContainsKey(key))
				lngFile = (string)settingsLst[key];
			mlng.LoadLNG(lngFile);
			this.Text = mlng.SetLanguage(this.Controls, this.Menu, this.Text);
			//Language ID
			key = ApplicationConstants.languageIDstr;
			if(settingsLst.ContainsKey(key))
				this.curLngIndex = Convert.ToByte(settingsLst[key]);
			//BackgroundColor
			key = ApplicationConstants.backcolorstr;
			tmp = ApplicationConstants.blackstr;
			if(settingsLst.ContainsKey(key))
				tmp = Convert.ToString(settingsLst[key]);
			if(tmp.ToUpper() == ApplicationConstants.blackstr)
				this.cadEditorControl.Black_Click();
			else 
				this.cadEditorControl.White_Click();
			//Show entity panel
			key = ApplicationConstants.showentitystr;
			if(settingsLst.ContainsKey(key))
				tmp = Convert.ToString(settingsLst[key]);
			if(tmp.ToUpper() == ApplicationConstants.truestr) 
				this.cadEditorControl.EntityTreeVisible = true;
			else
				this.cadEditorControl.EntityTreeVisible = false;
			//Color drawing
			key = ApplicationConstants.drawmodestr;
			if(settingsLst.ContainsKey(key))
				tmp = Convert.ToString(settingsLst[key]);
			if(tmp.ToUpper() == ApplicationConstants.truestr) 
				this.cadEditorControl.ColorDraw = true;
			else 
				this.cadEditorControl.ColorDraw = false;
			//SHXPathCount
			key = ApplicationConstants.shxpathcnstr;
			if(settingsLst.ContainsKey(key))
				cn = Convert.ToInt32(settingsLst[key]);
			//SHXPaths
			for(int i = 0; i < cn; i++)
			{
				key = string.Format("SHXPath_{0}", (i + 1));
				if(settingsLst.ContainsKey(key))
					this.cadEditorControl.SHXForm.AddPath(Convert.ToString(settingsLst[key]));
			}
			//First start
			key = ApplicationConstants.installstr;
			if(settingsLst.ContainsKey(key))
			{
				if(CADImport.CADConst.SearchSHXPaths)
				{
					this.cadEditorControl.SHXForm.lstDir.Items.Clear();
					this.cadEditorControl.SHXForm.lstPath.Clear();
					ArrayList vPaths = new ArrayList();
					CADImport.CADConst.FindAutoCADSHXPaths(vPaths);
					for(int i = 0; i < vPaths.Count; i++)
					{
						tmp = (string)vPaths[i];
						this.cadEditorControl.SHXForm.lstDir.Items.Add(tmp);
						this.cadEditorControl.SHXForm.lstPath.Add(tmp, string.Empty);
						CADImport.CADConst.SHXSearchPaths += CADImport.CADConst.SHXSearchPaths + tmp + ApplicationConstants.sepstr3;
					}
				}
			}
			#region protect
#if protect			
			key = ApplicationConstants.typelcstr;
			if(settingsLst.ContainsKey(key))
			{
				tmp = (string)settingsLst[key];
#if floatprotect
				if(tmp == ApplicationConstants.floatingstr)
				{
					CADImport.Protection.LicenseType = CADImport.LicenseType.Floating;
					key = ApplicationConstants.hoststr;
					if(settingsLst.ContainsKey(key))
					{
						this.cadEditorControl.FloatingRegistrationForm.Host = (string)settingsLst[key];
					}
					key = ApplicationConstants.portstr;
					if(settingsLst.ContainsKey(key))
					{
						this.cadEditorControl.FloatingRegistrationForm.Port = Convert.ToInt32(settingsLst[key]);
					}
					key = ApplicationConstants.appconst;
					if(settingsLst.ContainsKey(key))
					{
						this.cadEditorControl.FloatingRegistrationForm.App = (string)settingsLst[key];
					}
				}
				else
				{
					CADImport.Protection.LicenseType = CADImport.LicenseType.Register;
				}
#else
					CADImport.Protection.LicenseType = LicenseType.Register;
#endif
			}
#endif
			#endregion
		}		

		private void CreateNewSettingsList()
		{
			string tmp; 
			settingsLst = new SortedList();
			//Language path
			settingsLst.Add(ApplicationConstants.languagepath, mlng.Path);
			//Language
			settingsLst.Add(ApplicationConstants.languagestr, lngFile);
			//Language ID
			settingsLst.Add(ApplicationConstants.languageIDstr, this.curLngIndex);
			//BackgroundColor
			if(cadEditorControl.EditorCADPictureBox.BackColor == Color.Black)
				tmp = ApplicationConstants.blackstr;
			else tmp = ApplicationConstants.whitestr;
			settingsLst.Add(ApplicationConstants.backcolorstr, tmp);
			//Show entity panel
			settingsLst.Add(ApplicationConstants.showentitystr, cadEditorControl.EntityTreeVisible);
			//Color drawing
			if(this.cadEditorControl.Image != null)
				settingsLst.Add(ApplicationConstants.colorDraw, (this.cadEditorControl.Image.DrawMode == CADImport.CADDrawMode.Normal));
			else
				settingsLst.Add(ApplicationConstants.colorDraw, this.cadEditorControl.ColorDraw);
			//SHXPathCount
			int cn = cadEditorControl.SHXForm.lstDir.Items.Count;
			settingsLst.Add(ApplicationConstants.shxpathcnstr, cadEditorControl.SHXForm.lstDir.Items.Count);
			//SHXPaths
			for(int i = 0; i < cn; i++)
			{
				settingsLst.Add("SHXPath_" + (i + 1), cadEditorControl.SHXForm.lstDir.Items[i]);
			}
			this.cadEditorControl.NewProtectionSettings(settingsLst);
		}	

		private void SelectLanguage()
		{
			for(int i = 0; i < this.mainMenu.MenuItems[4].MenuItems[0].MenuItems.Count; i++)
				if(this.mainMenu.MenuItems[4].MenuItems[0].MenuItems[i].Text == "English")
				{
					this.mainMenu.MenuItems[4].MenuItems[0].MenuItems[i].Checked = true;
					this.curLngIndex = i;
					break;
				}
		}		

		internal void ReloadLNG()
		{			
			mlng.LoadLngFileList(this.mainMenu.MenuItems[4].MenuItems[0], new System.EventHandler(LanguageSelect_Click));
		}
	
		private void miOpenFile_Click(object sender, System.EventArgs e)
		{
			this.cadEditorControl.LoadFile(true);
		}

		private void cadEditorControl_EndLoadFile(bool val)
		{	
			if(val)
				EnableMenuItems(true);
		}

		#region Help
		/// <summary>
		/// Enables menu items
		/// </summary>
		/// <param name="val">If <b>true</b> menu items are enabled, else - disabled</param>
		#endregion
		public void EnableMenuItems(bool val)
		{
			#region Export
#if Export
			this.miSaveAsDXF.Enabled = val;
#endif
			#endregion
			miScale.Enabled = val;
			miSaveFile.Enabled = val;
			miCopyAsBMP.Enabled = val;
			miZoomIn.Enabled = val;
			miZoomOut.Enabled = val;
			miFit.Enabled = val;
			miColorMode.Enabled = val;
			miBlackMode.Enabled = val;
			miWhiteBack.Enabled = val;
			miBlackBack.Enabled = val;
			miShowLineWeight.Enabled = val;
			miArcsSplit.Enabled = val;
			miDimShow.Enabled = val;
			miTextsShow.Enabled = val;
			miLayersShow.Enabled = val;			
			miClose.Enabled = val;
			miPrint.Enabled = val;
			miPrintCustom.Enabled = val;
			miPrintPrev.Enabled = val;
			miUndo.Enabled = val;
			miRedo.Enabled = val;
			miDelete.Enabled = val;
			miCopy.Enabled = val;
			miPaste.Enabled = val;
			miCut.Enabled = val;
		}

		private void miAbout_Click(object sender, System.EventArgs e)
		{
			this.cadEditorControl.AboutForm.ShowDialog();
		}

		private void miFloatLic_Click(object sender, System.EventArgs e)
		{
			#region floatprotect
			#if floatprotect
			this.cadEditorControl.FloatLicForm.ShowDialog();
			#endif
			#endregion
		}

		private void miRegister_Click(object sender, System.EventArgs e)
		{
			#region protect
			#if protect
			this.cadEditorControl.RegForm.ShowDialog();
			#endif
			#endregion
		}

		private void miSaveFile_Click(object sender, System.EventArgs e)
		{
			this.cadEditorControl.SaveAsImage(true);
		}

		private void miSaveAsDXF_Click(object sender, System.EventArgs e)
		{
			#region Export
			#if Export
			this.cadEditorControl.SaveAsDXF(true);
			#endif
			#endregion Export			
		}

		private void miPrint_Click(object sender, System.EventArgs e)
		{
			this.cadEditorControl.Image.Print(true, true);
		}

		private void miPrintCustom_Click(object sender, System.EventArgs e)
		{
			this.cadEditorControl.ShowCustomPrintPreviewDialog();
		}

		private void miPrintPrev_Click(object sender, System.EventArgs e)
		{
			this.cadEditorControl.ShowPrintPreviewDialog();
		}

		private void miExit_Click(object sender, System.EventArgs e)
		{
			this.Close();
		}

		private void miClose_Click(object sender, System.EventArgs e)
		{
			this.cadEditorControl.CloseFile();
		}

		private void miCopyAsBMP_Click(object sender, System.EventArgs e)
		{
			this.cadEditorControl.PutToClipboard();
		}

		private void miUndo_Click(object sender, System.EventArgs e)
		{
			this.cadEditorControl.UndoChangeEntity();
		}

		private void miRedo_Click(object sender, System.EventArgs e)
		{
			this.cadEditorControl.RedoChangeEntity();
		}

		private void miDelete_Click(object sender, System.EventArgs e)
		{
			this.cadEditorControl.DeleteSelectedEntities();
		}

		private void miCopy_Click(object sender, System.EventArgs e)
		{
			this.cadEditorControl.Image.CopyEntities();
		}

		private void miCut_Click(object sender, System.EventArgs e)
		{
			this.cadEditorControl.Image.CutEntities();
			this.cadEditorControl.EditorCADPictureBox.Invalidate();
		}

		private void miPaste_Click(object sender, System.EventArgs e)
		{
			this.cadEditorControl.Image.PasteEntities();
			this.cadEditorControl.EditorCADPictureBox.Invalidate();
		}

		private void miShowEntitiesPanel_Click(object sender, System.EventArgs e)
		{
			propPnVisible = ! propPnVisible;
			this.cadEditorControl.PropertyEntityPanelVisible = propPnVisible;
			this.miShowEntitiesPanel.Checked = propPnVisible;
		}

		private void miZoomIn_Click(object sender, System.EventArgs e)
		{
			this.cadEditorControl.DoZoomIn();
		}

		private void miZoomOut_Click(object sender, System.EventArgs e)
		{
			this.cadEditorControl.DoZoomOut();
		}

		private void miFit_Click(object sender, System.EventArgs e)
		{
			this.cadEditorControl.CalculateNewSizeImage();
		}

		private void miShowSHXForm_Click(object sender, System.EventArgs e)
		{
			this.cadEditorControl.SHXForm.ShowDialog();
		}

		private void miOptions_Click(object sender, System.EventArgs e)
		{
			this.cadEditorControl.EntitiesCreator.OptionsForm.ShowDialog();
		}

		private void miColorMode_Click(object sender, System.EventArgs e)
		{
			this.cadEditorControl.ColorDraw = true;			
			this.miColorMode.Checked = true;
			this.miBlackMode.Checked = false;			
		}

		private void miBlackMode_Click(object sender, System.EventArgs e)
		{
			this.cadEditorControl.ColorDraw = false;			
			this.miColorMode.Checked = false;
			this.miBlackMode.Checked = true;			
		}

		private void miWhiteBack_Click(object sender, System.EventArgs e)
		{									
			this.whiteBackGround = true;
			this.blackBackGround = false;	
			ChangeBackground();
		}

		private void ChangeBackground()
		{
			this.miWhiteBack.Checked = this.whiteBackGround;		
			this.miBlackBack.Checked = this.blackBackGround;								
			if(this.whiteBackGround)
				this.cadEditorControl.SetWhiteBackGround();
			if(this.blackBackGround)
				this.cadEditorControl.SetBlackBackGround();
		}

		private void miShowLineWeight_Click(object sender, System.EventArgs e)
		{
			showLineWeight = ! showLineWeight;
			this.cadEditorControl.ShowLineWeight = showLineWeight;			
			this.miShowLineWeight.Checked = showLineWeight;					
		}

		private void miArcsSplit_Click(object sender, System.EventArgs e)
		{
			this.useWinEllipse = ! this.useWinEllipse;
			this.cadEditorControl.UseWinEllipse(useWinEllipse);
			this.miArcsSplit.Checked = ! useWinEllipse;			
		}

		private void miDimShow_Click(object sender, System.EventArgs e)
		{
			dimVisible = ! dimVisible;
			this.cadEditorControl.DimensionVisible = dimVisible;
			this.miDimShow.Checked = dimVisible;
		}

		private void miBlackBack_Click(object sender, System.EventArgs e)
		{
			this.whiteBackGround = false;
			this.blackBackGround = true;
			ChangeBackground();
		}

		private void miTextsShow_Click(object sender, System.EventArgs e)
		{
			textVisible = ! textVisible;
			this.cadEditorControl.TextVisible = textVisible;
			this.miTextsShow.Checked = textVisible;		
		}

		private void miLayersShow_Click(object sender, System.EventArgs e)
		{
			this.cadEditorControl.LayerForm.ShowDialog();
		}

		private void miZoom_Click(object sender, System.EventArgs e)
		{
			float i = 1.0f;
			switch((sender as MenuItem).Index)
			{
				case 0:
					i = 0.1f;
					break;
				case 1:
					i = 0.25f;
					break;
				case 2:
					i = 0.5f;
					break;
				case 3:
					i = 1;
					break;
				case 4:
					i = 2;
					break;
				case 5:
					i = 4;
					break;
				case 6:
					i = 8;
					break;
			}
			this.cadEditorControl.SetScale(i);
		}

		private void MainForm_Closing(object sender, System.ComponentModel.CancelEventArgs e)
		{
			CreateNewSettingsList();
			svSet.SaveOptions(settingsLst);
		}					
	}

	
	internal abstract class ApplicationConstants
	{
		public static readonly string defaultstr;
		public static readonly string languagepath;		
		public static readonly string msgBoxDebugCaption;
		public static readonly string sepstr;
		public static readonly string notsupportedstr;
		public static readonly string notsupportedextstr;
		public static readonly string appnamestr;
		public static readonly string sepstr2;							
		public static readonly string lngextstr;
		public static readonly string languagestr;
		public static readonly string languageIDstr;
		public static readonly string backcolorstr;
		public static readonly string blackstr;
		public static readonly string showentitystr;
		public static readonly string drawmodestr;
		public static readonly string truestr;
		public static readonly string shxpathcnstr;
		public static readonly string installstr;
		public static readonly string sepstr3;
		public static readonly string typelcstr;
		public static readonly string floatingstr;
		public static readonly string hoststr;
		public static readonly string portstr;
		public static readonly string appconst;
		public static readonly string blackstr2;
		public static readonly string whitestr;
		public static readonly string registerstr;		
		public static readonly string namestr;
		public static readonly string visiblestr;
		public static readonly string freezestr;
		public static readonly string colorstr;		
		public static readonly string colorDraw;

		static ApplicationConstants()
		{
			defaultstr = "Default";
			languagepath = "LanguagePath";			
			msgBoxDebugCaption = "Debug application message";
			sepstr = " - ";
			notsupportedstr = "not supported";
			notsupportedextstr = "Not supported in current version!";
			appnamestr = "CADImportNet Demo";
			sepstr2 = " : ";						
			lngextstr = ".lng";
			languagestr = "Language";
			languageIDstr = "LanguageID";
			backcolorstr = "BackgroundColor";
			blackstr = "BLACK";
			showentitystr = "ShowEntity";
			drawmodestr = "drawMode";
			truestr = "TRUE";
			shxpathcnstr = "SHXPathCount";
			installstr = "Install";
			sepstr3 = ";";
			typelcstr = "Type_license";
			floatingstr = "floating";
			hoststr = "Host";
			portstr = "Port";
			appconst = "Application";
			blackstr2 = "Black";
			whitestr = "White";
			registerstr = "register";			
			namestr = "Name";
			visiblestr = "Visible";
			freezestr = "Freeze";
			colorstr = "Color";			
			colorDraw = "ColorDraw";
		}
	}
}
